;+
; .. _fig1_no_obs_map.pro:
;
; ===================
; fig1_no_obs_map.pro
; ===================
;
; DESCRIPTION
; ===========
;
; :file:`${PROJECT_OD}/mask_oaflux_30N30S.nc`
; containing OAFLUX grid
; has been produced by :ref:`oaflux_mask_30N30S.pro`.
;
; Figure of
; ++
; is saved in
; :file:`${PROJECT_OD}/fig1_no_obs_map.ps`.
;
; .. graphviz::
;
;    digraph fig1_no_obs_map {
;
;       mask [shape=ellipse,fontname=Courier,label="${PROJECT_OD}/mask_oaflux_30N30S.nc"];
;       lhf_no_obs [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/lhf_no_obs.txt"];
;       sw_no_obs [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/sw_no_obs.txt"];
;       lw_no_obs [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/lw_no_obs.txt"];
;       figure [shape=ellipse,fontname=Courier,label="${PROJECT_OD}/fig1_no_obs_map.ps"];
;
;       fig1_no_obs_map [shape=box,
;       fontname=Courier,
;       color=blue,
;       URL="http://forge.ipsl.jussieu.fr/tropflux/browser/trunk/src/paper01/fig1/fig1_no_obs_map.pro",
;       label="${TROPFLUX}/src/paper01/fig1/fig1_no_obs_map.pro"];
;
;       {mask lhf_no_obs sw_no_obs lw_no_obs} -> {fig1_no_obs_map} -> {figure}
;
;    }
;
; SEE ALSO
; ========
;
; :ref:`data_in_oaflux`
;
; :ref:`project_profile.sh`
; :ref:`project_init.pro`
;
; :func:`x_site_location`
; :func:`y_site_location`
;
; :ref:`oaflux_mask_30N30S.pro`
;
; EXAMPLES
; ========
;
; ::
;
;  IDL> fig1_no_obs_map
;
; TODO
; ====
;
; how text files have been produced ?
;
; coding rules
;
; complete description
;
; handle IO error
;
; EVOLUTIONS
; ==========
;
; $Id$
;
; - fplod 20110817T104358Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * get rid of spawn
;
; - pinsard 2011-04-20T15:08:28Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * make it work on loholt1
;
; - fplod 20110420T134821Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * externalize functions
;
; - fplod 20110412T073818Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * make it work on cratos
;   * remove hard coding path
;   * add graphviz
;
; - fplod 20110411T142955Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * minimal header
;
;-
pro fig1_no_obs_map
;
@cm_4cal
@cm_4data
@cm_4mesh
@cm_4data
@cm_project
;
reinitplt, /z,/invert
key_portrait = 1
;
openps, FILENAME = project_od_env + 'fig1_no_obs_map.ps'
close,/all
;
yr=365.
lh_mi=365/yr
lh_ma=3285/yr
lh_int=0.25
sw_mi=365/yr
sw_ma=3285/yr
sw_int=0.25
lw_mi=365/yr
lw_ma=1460/yr
lw_int=0.125
lct=65
;
file=project_id_env + 'mask_oaflux_30N30S.nc'
initncdf, file
domdef, 30,390,-30,30
msk=ncdf_lec(file,var='msk')
;
fi=project_id_env + 'lhf_no_obs.txt'
res=read_ascii(fi,data_start=1)
ff=res.field1
lat=reform(ff(0,*))
lon=reform(ff(1,*))
no=reform(ff(2,*))
no=no/yr
;ind=where(no ge lh_ma)
; no(ind)=no-0.5
;
marge1=[0,0,-5,0]
plt, .4+msk*1.e-5,realcont=2,/nocont,/nofill,xminor=1,yminor=1,box=box,lct=lct, lh_mi, lh_ma, int=lh_int, $
   title='a) Turbulent Flux validation sites', subtitle='', small=[1,4,1],/rempl, marge=marge1, format='(i5)'
NN=n_elements(lat)
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5],/fill
;
for n=0,NN-1 do begin
  x=lon[n]
  y=lat[n]
  c=no[n]
  cmi=lh_mi
  cma=lh_ma
  dc=cma-cmi
  col=((10+244*(c-cmi)/dc) > 10) < 254
  plots, x,y,psym=8,symsize=1.5,color=col
endfor
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5]
;
for n=0,NN-1 do begin
  x=lon[n]
  y=lat[n]
  c=no[n]
;
  plots, x,y,psym=8,symsize=1.5,color=0
endfor
;
fi=project_id_env + 'sw_no_obs.txt'
res=read_ascii(fi,data_start=1)
ff=res.field1
lat=reform(ff(0,*))
lon=reform(ff(1,*))
no=reform(ff(2,*))
no=no/yr
;ind=where(no ge sw_ma)
;no(ind)=sw_ma-0.5
marge1=[0,0,-5,0]
plt, .4+msk*1.e-5,realcont=2,/nocont,/nofill,xminor=1,yminor=1,box=box,lct=lct, sw_mi, sw_ma, int=sw_int, $
   title='b) SWR validation sites', subtitle='', small=[1,4,2],/noer,/rempl, marge=marge1, format='(i5)'
NN=n_elements(lat)
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5],/fill
;
for n=0,NN-1 do begin
  x=lon[n]
  y=lat[n]
  c=no[n]
  cmi=sw_mi
  cma=sw_ma
  dc=cma-cmi
  col=((10+244*(c-cmi)/dc) > 10) < 254
  plots, x,y,psym=8,symsize=1.5,color=col
endfor
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5]
;
for n=0,NN-1 do begin
  x=lon[n]
  y=lat[n]
  c=no[n]
;
  plots, x,y,psym=8,symsize=1.5,color=0
endfor
;
fi=project_id_env + 'lw_no_obs.txt'
res=read_ascii(fi,data_start=1)
ff=res.field1
lat=reform(ff(0,*))
lon=reform(ff(1,*))
no=reform(ff(2,*))
no=no/yr
;ind=where(no ge lw_ma)
;no(ind)=lw_ma-0.25
;
marge1=[0,0,-5,0]
plt, .4+msk*1.e-5,realcont=2,/nocont,/nofill,/noer,xminor=1,yminor=1,box=box,lct=lct,lw_mi, lw_ma, int=lw_int, $
   title='c) LWR validation sites', subtitle='', small=[1,4,3],/rempl, marge=marge1, format='(i5)'
NN=n_elements(lat)
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5],/fill
;
for n=0,NN-1 do begin
  x=lon[n]
  y=lat[n]
  c=no[n]
  cmi=lw_mi
  cma=lw_ma
  dc=cma-cmi
  col=((10+244*(c-cmi)/dc) > 10) < 254
  plots, x,y,psym=8,symsize=1.5,color=col
endfor
;
usersym, [-.5,.5,.5,-.5,-.5],[-.5,-.5,.5,.5,-.5]
;
for n=0,NN-1 do begin
  x=lon[n]
  y=lat[n]
  c=no[n]
;
  plots, x,y,psym=8,symsize=1.5,color=0
endfor
;
; independent validation sites
;
plots, 61.5, 15.5,psym=2      ; as location
plots, 331, 25.5,psym=2       ; subduction (central)
plots, 326, 18,psym=2         ; subduction (sw)
plots, 338, 18,psym=2         ; subduction (se)
plots, 156, -1.7 , psym=2     ; coare
plots, 274.2, -21, psym=2     ; stratus
plots, 202.46, 22.45, psym=2  ; WHOTS
;
closeps
;
end
